#
# spec file for package ltris2
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ltris2
Version:        2.0.3
Release:        1.1
Summary:        Tetris Clone with Multiplayer and CPU Opponents
License:        GPL-3.0-or-later
URL:            https://github.com/kulkanie/ltris2
Source:         https://download.sourceforge.net/lgames/ltris/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(SDL2_image)
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(SDL2_ttf)

%lang_package

%description
LTris2 is a highly configurable, polished, HD-screen ready Tetris clone. It
offers the well-known Classic game, a funny game type Figures (a new figure
each level, suddenly appearing tiles and lines), and multiplayer against up
to two CPU players or human versus human.

%prep
%autosetup -p1

%build
%configure \
  %{nil}
%make_build

%install
%make_install
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_datadir}/%{name}

%files
%license COPYING
%doc Changelog README
%{_bindir}/ltris2
%{_datadir}/ltris2/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
# Do not use world-writable hiscore file
%exclude %{_localstatedir}/%{name}.hscr

%files lang -f %{name}.lang

%changelog
* Sat Nov 30 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 2.0.3
  * added three different window modes: 66%%, 50%% and 25%% of screen
    height to allow more choice with all the different resolutions
    and monitor sizes.
    The previous window mode was 66%% and could be quite large on
    bigger 4k monitors.
* Sat Oct 12 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 2.0.2
  * apply autoshift changes to current game.
  * added custom cursor and hide it while playing.
  * CPU player names include settings.
  * changed step for cpu speed factor to 10%%.
  * fixed bug in key handling.
* Wed Sep  4 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.0.1:
  * Count score faster (2024/09/03 MS)
  * Use special block for sent garbage lines (2024/09/03 MS)
  * Allow changing fps during game (2024/09/03 MS)
  * Fixed crash due to bad pixel mask for dummy surfaces
    (2024/09/03 MS)
  * Fixed return type warnings (2024/09/03 Atri)
  * Fixed path for local hiscore file (2024/09/03 Atri)
- Correct License tag: GPL-3.0-or-later instead of 2.0.
- Drop patches incorporated upstream:
  * ltris2-control-reaches-non-void.patch
  * ltris2-hiscore-file-path.patch
- Split off lang package.
* Tue Jul 30 2024 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
- Add ltris2-control-reaches-non-void.patch: Fix non-void
  functions reaching end of control without returning
- Add ltris2-hiscore-file-path.patch: Fix path of hiscore file
  when the leading char is '~'.
